@@ -26,8 +26,7 @@ class RawDatabasesAPI(APIClient):
 
         Args:
             chunk_size (int, optional): Number of dbs to return in each chunk. Defaults to yielding one db a time.
-            limit (int, optional): Maximum number of assets to return. Defaults to 25. Set to -1, float("inf") or None
-                to return all items.
+            limit (int, optional): Maximum number of dbs to return. Defaults to return all items.
         """
         return self._list_generator(chunk_size=chunk_size, method="GET", limit=limit)
 
@@ -139,8 +138,7 @@ class RawTablesAPI(APIClient):
         Args:
             db_name (str): Name of the database to iterate over tables for
             chunk_size (int, optional): Number of tables to return in each chunk. Defaults to yielding one table a time.
-            limit (int, optional): Maximum number of assets to return. Defaults to 25. Set to -1, float("inf") or None
-                to return all items.
+            limit (int, optional): Maximum number of tables to return. Defaults to return all items.
         """
         for tb in self._list_generator(
             resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name),
@@ -271,6 +269,7 @@ class RawRowsAPI(APIClient):
     def __init__(self, config: utils._client_config.ClientConfig, api_version: str = None, cognite_client=None):
         super().__init__(config, api_version, cognite_client)
         self._CREATE_LIMIT = 10000
+        self._LIST_LIMIT = 10000
 
     def __call__(
         self, db_name: str, table_name: str, chunk_size: int = None, limit: int = None
@@ -283,8 +282,7 @@ class RawRowsAPI(APIClient):
             db_name (str): Name of the database
             table_name (str): Name of the table to iterate over rows for
             chunk_size (int, optional): Number of rows to return in each chunk. Defaults to yielding one row a time.
-            limit (int, optional): Maximum number of assets to return. Defaults to 25. Set to -1, float("inf") or None
-                to return all items.
+            limit (int, optional): Maximum number of rows to return. Defaults to return all items.
         """
         return self._list_generator(
             resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, db_name, table_name),
@@ -328,7 +326,7 @@ class RawRowsAPI(APIClient):
         ]
         summary = utils._concurrency.execute_tasks_concurrently(self._post, tasks, max_workers=self._config.max_workers)
         summary.raise_compound_exception_if_failed_tasks(
-            task_unwrap_fn=lambda task: task["json"]["items"], task_list_element_unwrap_fn=lambda row: row["key"]
+            task_unwrap_fn=lambda task: task["json"]["items"], task_list_element_unwrap_fn=lambda row: row.get("key")
         )
 
     def _process_row_input(self, row: List[Union[List, Dict, Row]]):
